@@ -1108,9 +1108,6 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1572,9 +1569,6 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
